==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/GeographicTileSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { TileSeries } from "./TileSeries";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { runOn, delegateRemove, delegateCombine, markType } from "igniteui-webcomponents-core";
import { ImageTilesReadyEventArgs } from "./ImageTilesReadyEventArgs";
/**
 * @hidden
 */
export let GeographicTileSeries = /*@__PURE__*/ (() => {
    class GeographicTileSeries extends GeographicShapeSeriesBase {
        bc() {
            return new GeographicTileSeries();
        }
        get_fh() {
            return true;
        }
        constructor() {
            super();
            this.vc = null;
            this.vb = null;
            this.imageTilesReady = null;
            this.ab = GeographicTileSeries.$;
        }
        get vd() {
            return this.vc;
        }
        set vd(a) {
            let b = a != this.vd;
            if (b) {
                let c = this.vd;
                this.vc = a;
                this.raisePropertyChanged("TileImagery", c, a);
            }
        }
        vh() {
            if (this.vd != null) {
                this.vd.clearTileCache();
            }
        }
        pa(a, b, c, d) {
            super.pa(a, b, c, d);
            switch (b) {
                case "TileImagery":
                    if (this.t5 != null) {
                        this.t5.wy = this.vd;
                    }
                    break;
            }
        }
        ua() {
            super.ua();
            this.t5.wy = this.vd;
            if (this.vb != null) {
                let a = this.vb;
                a.imageTilesReady = delegateRemove(a.imageTilesReady, runOn(this, this.vg));
            }
            this.vb = this.t5;
            if (this.vb != null) {
                let b = this.vb;
                b.imageTilesReady = delegateCombine(b.imageTilesReady, runOn(this, this.vg));
            }
        }
        t4() {
            return new TileSeries();
        }
        vg(a, b) {
            if (this.imageTilesReady != null) {
                this.imageTilesReady(this, new ImageTilesReadyEventArgs());
            }
        }
    }
    GeographicTileSeries.$t = /*@__PURE__*/ markType(GeographicTileSeries, 'GeographicTileSeries', GeographicShapeSeriesBase.$);
    return GeographicTileSeries;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/GeographicTileSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { TileSeries } from "./TileSeries";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { runOn, delegateRemove, delegateCombine, markType } from "igniteui-webcomponents-core";
import { ImageTilesReadyEventArgs } from "./ImageTilesReadyEventArgs";
/**
 * @hidden
 */
export let GeographicTileSeries = /*@__PURE__*/ (() => {
    class GeographicTileSeries extends GeographicShapeSeriesBase {
        bk() {
            return new GeographicTileSeries();
        }
        get_f3() {
            return true;
        }
        constructor() {
            super();
            this.yi = null;
            this.yh = null;
            this.imageTilesReady = null;
            this.ab = GeographicTileSeries.$;
        }
        get yj() {
            return this.yi;
        }
        set yj(a) {
            let b = a != this.yj;
            if (b) {
                let c = this.yj;
                this.yi = a;
                this.raisePropertyChanged("TileImagery", c, a);
            }
        }
        yn() {
            if (this.yj != null) {
                this.yj.clearTileCache();
            }
        }
        ra(a, b, c, d) {
            super.ra(a, b, c, d);
            switch (b) {
                case "TileImagery":
                    if (this.w2 != null) {
                        this.w2.aad = this.yj;
                    }
                    break;
            }
        }
        w7(a, b) {
            super.w7(a, b);
            this.w2.aad = this.yj;
            if (this.yh != null) {
                let c = this.yh;
                c.imageTilesReady = delegateRemove(c.imageTilesReady, runOn(this, this.ym));
            }
            this.yh = this.w2;
            if (this.yh != null) {
                let d = this.yh;
                d.imageTilesReady = delegateCombine(d.imageTilesReady, runOn(this, this.ym));
            }
        }
        w1() {
            return new TileSeries();
        }
        ym(a, b) {
            if (this.imageTilesReady != null) {
                this.imageTilesReady(this, new ImageTilesReadyEventArgs());
            }
        }
    }
    GeographicTileSeries.$t = /*@__PURE__*/ markType(GeographicTileSeries, 'GeographicTileSeries', GeographicShapeSeriesBase.$);
    return GeographicTileSeries;
})();
